pub enum LocalKind {
Input,
Binding,
Output,
Consumer,
}Expand description
The role of a value in one function invocation. 一个函数调用中局部值的角色。
Variants
Input
A value passed into the invocation. 调用传入的值。
Binding
A value bound inside the invocation body. 在调用体内绑定的值。
Output
A value the invocation returns. 调用返回的值。
Consumer
A value handed to a function as one of its parameters. 作为某个函数参数被消费的值。
Implementations